@@ -118,11 +118,6 @@ sub has_vimball {
     return undef;
 }
 
-sub set_record {
-    my ( $self , $package , $pkgfiles ) =  @_;
-    # Vimana::Record->set_record(  cname => $package , files => [ $pkgfiles ]  );
-}
-
 sub auto_install {
     my $self = shift;
     my %args = @_;
